/*++

Copyright (c) 2012-2013 ELMOS Co., Ltd.

Module Name:
	EPX18QC.h
Abstract:
	EPX-18QC API library definitions
Revision History:
	12/10/12	Created.
	13/05/01	Support for Windows 8.

--*/

#ifndef EPX18QC_H
#define EPX18QC_H

#ifdef EPX18QC_EXPORTS_
#define EPX18QC_API __declspec(dllexport)
#else
#define EPX18QC_API __declspec(dllimport)
#endif

//
// Device handle
//
typedef void *EPX18QC_HANDLE;

//
// Device status (Return Value)
//
enum {
	EPX18QC_OK,
	EPX18QC_INVALID_HANDLE,
	EPX18QC_DEVICE_NOT_FOUND,
	EPX18QC_DEVICE_NOT_OPENED,
	EPX18QC_OTHER_ERROR,
	EPX18QC_COMMUNICATION_ERROR,
	EPX18QC_INVALID_PARAMETER
};

//
// Counter CH
//
#define EPX18QC_CNT_CH0	0
#define EPX18QC_CNT_CH1	1
#define EPX18QC_CNT_CH2	2
#define EPX18QC_CNT_CH3	3

//
// Counter Mode
//
#define EPX18QC_CNT_MODE_1PHASE	0
#define EPX18QC_CNT_MODE_2PHASE	1

//
// Counter Direction
//
#define EPX18QC_CNT_DIR_UP		0
#define EPX18QC_CNT_DIR_DOWN	1

//
// Counter Control
//
#define EPX18QC_CNT_DISABLE	0
#define EPX18QC_CNT_ENABLE	1

//
// Counter Status
//
#define EPX18QC_CNT_OK		0
#define EPX18QC_CNT_OVF		1
#define EPX18QC_CNT_UDF		2

//
// Counter External Control
//
#define EPX18QC_CNT_EX_DISABLE	0
#define EPX18QC_CNT_EX_ENABLE	1

//
// Counter Latch Flag
//
#define EPX18QC_CNT_LAT_FALSE	0
#define EPX18QC_CNT_LAT_TRUE	1

//
// I/O Port
//
#define EPX18QC_PORT0	0
#define EPX18QC_PORT1	1
#define EPX18QC_PORT2	2

//
// Port Direction
//
#define EPX18QC_PORT_DIR_INPUT	0
#define EPX18QC_PORT_DIR_OUTPUT	1


#ifdef __cplusplus
extern "C" {
#endif

//
// Device Functions
//
EPX18QC_API int WINAPI EPX18QC_GetNumberOfDevices (int *Number);
EPX18QC_API int WINAPI EPX18QC_GetSerialNumber (int Index, int *SerialNumber);
EPX18QC_API int WINAPI EPX18QC_Open (EPX18QC_HANDLE *Handle);
EPX18QC_API int WINAPI EPX18QC_OpenBySerialNumber (int SerialNumber, EPX18QC_HANDLE *Handle);
EPX18QC_API int WINAPI EPX18QC_Close (EPX18QC_HANDLE Handle);

//
// Counter Functions
//
EPX18QC_API int WINAPI EPX18QC_SetCounterMode (EPX18QC_HANDLE Handle, BYTE CH, BYTE Mode);
EPX18QC_API int WINAPI EPX18QC_GetCounterMode (EPX18QC_HANDLE Handle, BYTE CH, BYTE *Mode);
EPX18QC_API int WINAPI EPX18QC_SetCounterDirection (EPX18QC_HANDLE Handle, BYTE CH, BYTE Direction);
EPX18QC_API int WINAPI EPX18QC_GetCounterDirection (EPX18QC_HANDLE Handle, BYTE CH, BYTE *Direction);
EPX18QC_API int WINAPI EPX18QC_SetCounterControl (EPX18QC_HANDLE Handle, BYTE CH, BYTE Control);
EPX18QC_API int WINAPI EPX18QC_GetCounterControl (EPX18QC_HANDLE Handle, BYTE CH, BYTE *Control);
EPX18QC_API int WINAPI EPX18QC_ResetCounter (EPX18QC_HANDLE Handle, BYTE CH);
EPX18QC_API int WINAPI EPX18QC_GetCounterValue (EPX18QC_HANDLE Handle, BYTE CH, int *Value);
EPX18QC_API int WINAPI EPX18QC_GetCounterStatus (EPX18QC_HANDLE Handle, BYTE CH, BYTE *Status);
EPX18QC_API int WINAPI EPX18QC_GetCounterExControl (EPX18QC_HANDLE Handle, BYTE CH, BYTE *Control);
EPX18QC_API int WINAPI EPX18QC_GetCounterLatchFlag (EPX18QC_HANDLE Handle, BYTE CH, BYTE *Flag);
EPX18QC_API int WINAPI EPX18QC_GetCounterLatchValue (EPX18QC_HANDLE Handle, BYTE CH, int *Value);

//
// I/O Port Functions
//
EPX18QC_API int WINAPI EPX18QC_SetPortDirection (EPX18QC_HANDLE Handle, BYTE Port, BYTE Direction);
EPX18QC_API int WINAPI EPX18QC_GetPortDirection (EPX18QC_HANDLE Handle, BYTE Port, BYTE *Direction);
EPX18QC_API int WINAPI EPX18QC_OutputPort (EPX18QC_HANDLE Handle, BYTE Port, BYTE Value);
EPX18QC_API int WINAPI EPX18QC_InputPort (EPX18QC_HANDLE Handle, BYTE Port, BYTE *Value);

#ifdef __cplusplus
}
#endif

#endif  /* EPX18QC_H */